class InboxTrackerException(Exception):
    pass


class InboxTrackerAPIException(InboxTrackerException):
    """Handle 4xx and 5xx errors from the API"""
    def __init__(self, response, *args, **kwargs):
        # noinspection PyBroadException
        try:
            errors = response.json()['errors']
            error_template = "{message} Code: {code} Description: {desc} \n"
            errors = [error_template.format(message=e.get('message', ''),
                                            code=e.get('code', 'none'),
                                            desc=e.get('description', 'none'))
                      for e in errors]
        # TODO: select exception to catch here
        except:  # noqa: E722
            errors = [response.text or ""]
        self.status = response.status_code
        self.response = response
        self.errors = errors
        message = """Call to {uri} returned {status_code}, errors:
        {errors}
        """.format(
            uri=response.url,
            status_code=response.status_code,
            errors='\n'.join(errors)
        )
        super(InboxTrackerAPIException, self).__init__(message, *args, **kwargs)



from .base import Resource

param_model = {
    'qd',
    'domain',
    'page',
    'per_page',
    'order'
}

class PostmasterTools:

    def __init__(self, base_uri, api_key):
        self.yahoo = Yahoo(base_uri, api_key)
        self.ping = Ping(base_uri, api_key)


class Yahoo(Resource):
    key = "yahoo"

    def get_domain_perf(self, **kwargs):
        """
        Get Yahoo Performance data rolled up at the domain level.

        :param str qd: A date range query parameter.

            Accepts:  ``since:YYYYMMDD``, ``between:YYYYMMDDhhmmss,YYYYMMDDhhmmss``, and ``daysBack:N``.

            Examples:  ``since:20190601``, ``between:20191001000000,20191002060000``, ``daysBack:30``
        :param domain: List of strings. The domains to filter on.
        :param int page: The page to query for in pagination.
        :param int per_page: The amount of records per page you wish to query for (max 100)
        :param str order: The property to sort by ('property' for decending, '-property' for ascending)

            Accepts:  ``domain``, ``-domain``, ``inboxVolume``, ``-inboxVolume``, ``spamVolume``, ``-spamVolume``,
            ``folderVolume``, ``-folderVolume``, ``errorVolume``, ``-errorVolume``, ``totalComplaints``,
            ``-totalComplaints``.

            Defaults to ``-inboxVolume``.

        :return: A ``list`` object of ``dict`` containing deliverability performance data.
        """
        endpoint = "/domain"
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse

    def get_ip_perf(self, **kwargs):
        """
        Get Yahoo Performance data grouped by IP address.

        :param str qd: A date range query parameter.

            Accepts:  ``since:YYYYMMDD``, ``between:YYYYMMDDhhmmss,YYYYMMDDhhmmss``, and ``daysBack:N``.

            Examples:  ``since:20190601``, ``between:20191001000000,20191002060000``, ``daysBack:30``

        :param domain: List of strings. The domains to filter on.
        :param ipAddress: List of strings. IP addresses to filter on.
        :param bool onlyComplaintErrorIps: Only return IPs that have errorVolume or totalComplaints greater than zero
            for the period given.
        :param int page: The page to query for in pagination.
        :param int per_page: The amount of records per page you wish to query for (max 100)
        :param str order: The property to sort by ('property' for decending, '-property' for ascending)

            Accepts:  ``ipAddress``, ``-ipAddress``, ``inboxVolume``, ``-inboxVolume``, ``spamVolume``, ``-spamVolume``,
            ``folderVolume``, ``-folderVolume``, ``errorVolume``, ``-errorVolume``, ``totalComplaints``,
            ``-totalComplaints``

        :return: A ``list`` object of ``dict`` containing deliverability performance data.
        """
        endpoint = "/ip"
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse

    def get_volume_over_time(self, **kwargs):
        """
        Volume over time for Yahoo Performance data grouped by the default grouping period:

            HOUR  when <= 7d

            DAY   when <= 31d

            WEEK  when <= 182d

            MONTH when >  182d

        :param str qd: A date range query parameter.

            Accepts:  ``since:YYYYMMDD``, ``between:YYYYMMDDhhmmss,YYYYMMDDhhmmss``, and ``daysBack:N``.

            Examples:  ``since:20190601``, ``between:20191001000000,20191002060000``, ``daysBack:30``

        :param domain: List of strings. The domains to filter on.
        :param sourceFilter: List of strings. The sources to use for inbox percentages.

            Accepts:  ``PANEL``, ``INTELLISEED``

            Defaults to all.

        :return: A ``list`` object of ``dict`` containing volume data.
        """
        endpoint = "/volume/over-time"
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse


class Ping(Resource):
    key = "ping"

    def ping_service(self):
        """
        Ping the service to verify it is reachable.

        :return:  A ``str`` object.  A successful ping will return the string 'pong'.
        """
        endpoint = ""
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters({}, {})
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse



import responses
from inboxtracker import InboxTracker


@responses.activate
def test_get_deliverability_by_domain():
    it = InboxTracker("fake-key")
    domain = "test-domain"
    qd = "test-qd"
    endpoint = "/" + str(domain)
    url = it.deliverability.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.deliverability.get_deliverability_by_domain(domain, qd=qd)
    assert json_output == 'yay'



from .campaigns import Campaigns
from .deliverability import Deliverability
from .domains import Domains
from .intelliseeds import Intelliseeds
from .ping import Ping
from .regions import Regions
from .seeds import Seeds
from .postmaster_tools import PostmasterTools
from .spam_trap import SpamTrap


__version__ = '1.2.1'
inboxTrackerURI = "api.edatasource.com"

inbox_module = '/inbox'
spam_trap_module = '/spam-trap'
postmaster_tools_module = '/postmaster-tools'

class InboxTracker(object):

    def __init__(self, api_key, base_uri=inboxTrackerURI, version="4"):

        self.base_uri = 'http://' + base_uri + '/v' + version
        self.api_key = api_key
        self.campaigns = Campaigns(self.base_uri + inbox_module, self.api_key)
        self.deliverability = Deliverability(self.base_uri + inbox_module, self.api_key)
        self.domains = Domains(self.base_uri + inbox_module, self.api_key)
        self.intelliseeds = Intelliseeds(self.base_uri + inbox_module, self.api_key)
        self.ping = Ping(self.base_uri + inbox_module, self.api_key)
        self.regions = Regions(self.base_uri + inbox_module, self.api_key)
        self.seeds = Seeds(self.base_uri + inbox_module, self.api_key)
        self.spam_trap = SpamTrap(self.base_uri + spam_trap_module, self.api_key)
        self.postmaster_tools = PostmasterTools(self.base_uri + postmaster_tools_module, self.api_key)



from .base import Resource

param_model = {
    'childAccountId',
    'partnerAccountId',
    'qd',
    'domain',
    'trapSource',
    'trapType',
    'ipAddress',
    'page',
    'per_page',
    'order',
    'campaignIdentifier',
    'subjectLine',
    'fromAddresses'
}

class SpamTrap:

    def __init__(self, base_uri, api_key):
        self.available_domains = AvailableDomains(base_uri, api_key)
        self.domain = Domain(base_uri, api_key)
        self.ip = IP(base_uri, api_key)
        self.ping = Ping(base_uri, api_key)


class AvailableDomains(Resource):
    key = "available-domains"

    def get_available_domains(self, **kwargs):
        """
        Gets the list of domains associated to your account/child accounts.

        :param int childAccountId: The child account to narrow results. This parameter is optional unless the API
            key is configured to require the childAccountId parameter.
        :param str partnerAccountId: The partnerAccountId associated with the childAccountId. This parameter is
            required by API keys configured to require the childAccountId-partnerAccountId parameters; otherwise the
            parameter is ignored.

        :return:  A ``list`` object of ``dict`` containing the domains available on the account.
        """
        endpoint = ""
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse


class Domain(Resource):
    key = "domain"

    def get_traps_by_domain(self, **kwargs):
        """
        Get a list of spam trap hits grouped by domain.

        :param str qd: A date range query parameter.

            Accepts:  ``since:YYYYMMDD``, ``between:YYYYMMDDhhmmss,YYYYMMDDhhmmss``, and ``daysBack:N``.

            Examples:  ``since:20190601``, ``between:20191001000000,20191002060000``, ``daysBack:30``

        :param domain: List of strings. The domains to filter on.
        :param trapSource: List of strings. The trap sources to filter on.

            Accepts:  ``ABUSIX``, ``CLOUDMARK``, ``SNDS``, ``GTN_PASSIVE``, ``GTN_ACTIVE``

        :param trapType: List of strings. The trap types to filter on.

            Accepts:  ``PRISTINE``, ``MIXED``, ``RECYCLED``, ``PARKED``, ``TYPO``

        :param ipAddress: List of strings. IP addresses to filter on. Accepts IP ranges, each IP range must be no
            larger that 256 IPs.
        :param int page: The page to query for in pagination.
        :param int per_page: The amount of records per page you wish to query for (max 100)
        :param str order: The property to sort by ('property' for decending, '-property' for ascending)

            Accepts:  ``domain``, ``-domain``, ``hitCountTotal``, ``-hitCountTotal``, ``hitCountRecycled``,
            ``-hitCountRecycled``, ``hitCountMixed``, ``-hitCountMixed``, ``hitCountParked``, ``-hitCountParked``,
            ``hitCountPristine``, ``-hitCountPristine``, ``hitCountTypo``, and ``-hitCountTypo``.

        :return:  A ``list`` object of ``dict`` containing spam trap hit counts
        """
        endpoint = ""
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse

    def get_domain_rollup(self, **kwargs):
        """
        Gets a list of aggregated detailed spam trap information and associated campaign information for sending
            domains. A details link is returned which can be used to retrieve the details for each of the spam trap
            hits included in the aggregated spam trap information.

        :param str qd: A date range query parameter.

            Accepts:  ``since:YYYYMMDD``, ``between:YYYYMMDDhhmmss,YYYYMMDDhhmmss``, and ``daysBack:N``.

            Examples:  ``since:20190601``, ``between:20191001000000,20191002060000``, ``daysBack:30``

        :param domain: List of strings. The domains to filter on.
        :param trapSource: List of strings. The trap sources to filter on.

            Accepts:  ``ABUSIX``, ``CLOUDMARK``, ``SNDS``, ``GTN_PASSIVE``, ``GTN_ACTIVE``

        :param trapType: List of strings. The trap types to filter on.

            Accepts:  ``PRISTINE``, ``MIXED``, ``RECYCLED``, ``PARKED``, ``TYPO``

        :param ipAddress: List of strings. IP addresses to filter on. Accepts IP ranges, each IP range must be no
            larger that 256 IPs.
        :param campaignIdentifier: List of strings. The campaign identifier used to identify the campaign when using a
            Campaign Identification method other than Subject/Date. Use the subjectLine filter if a domain is using
            Subject/Date to identify campaigns.
        :param subjectLine: List of strings. The subject lines to filter on.
        :param fromAddresses: List of strings. The "from" addresses to filter on.
        :param int page: The page to query for in pagination.
        :param int per_page: The amount of records per page you wish to query for (max 100)
        :param str order: The property to sort by ('property' for decending, '-property' for ascending)

            Accepts:  ``domain``, ``-domain``, ``hitCountTotal``, ``-hitCountTotal``, ``firstSeen``, ``-firstSeen``,
            ``lastSeen``, ``-lastSeen``, ``hitSources``, ``-hitSources``, ``trapTypes``, ``-trapTypes``,
            ``subjectLine``, ``-subjectLine``, ``campaign``, and ``-campaign``.

        :return: A ``list`` object of ``dict`` containing spam trap information
        """
        endpoint = "/rollup"
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse

    def get_domain_rollup_details(self, **kwargs):
        """
        Gets a list of spam trap hits with detailed information. It is recommended that this endpoint be accessed
            using the details link returned by the domain/rollup endpoint. To retrieve details for a campaign you must
            set a campaignId OR subjectLine filter for the campaign of interest. If you do not set a campaignId OR
            subjectLine filter you will only get detailed hits without an associated campaign.

        :param str qd: A date range query parameter.

            Accepts:  ``since:YYYYMMDD``, ``between:YYYYMMDDhhmmss,YYYYMMDDhhmmss``, and ``daysBack:N``.

            Examples:  ``since:20190601``, ``between:20191001000000,20191002060000``, ``daysBack:30``

        :param domain: List of strings. The domains to filter on.
        :param trapSource: List of strings. The trap sources to filter on.

            Accepts:  ``ABUSIX``, ``CLOUDMARK``, ``SNDS``, ``GTN_PASSIVE``, ``GTN_ACTIVE``

        :param trapType: List of strings. The trap types to filter on.

            Accepts:  ``PRISTINE``, ``MIXED``, ``RECYCLED``, ``PARKED``, ``TYPO``

        :param ipAddress: List of strings. IP addresses to filter on. Accepts IP ranges, each IP range must be no
            larger that 256 IPs.
        :param int campaignId: The campaign id used to filter on.
        :param str subjectLine: The subject line to filter on.
        :param fromAddresses: List of strings. The "from" addresses to filter on.
        :param int page: The page to query for in pagination.
        :param int per_page: The amount of records per page you wish to query for (max 100)
        :param str order: The property to sort by ('property' for decending, '-property' for ascending)

            Accepts:  ``domain``, ``-domain``, ``hitCountTotal``, ``-hitCountTotal``, ``firstSeen``, ``-firstSeen``,
            ``lastSeen``, ``-lastSeen``, ``ipAddress``, ``-ipAddress``, ``hitSources``, ``-hitSources``,
            ``subjectLine``, ``-subjectLine``, ``fromAddress``, ``-fromAddress``, ``trapAgeDays``, and ``-trapAgeDays``.

        :return: A ``list`` object of ``dict`` containing spam trap details for a campaign
        """
        endpoint = "/rollup/details"
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse


class IP(Resource):
    key = "ip"

    def get_traps_by_ip(self, **kwargs):
        """
        Get a list of spam trap hits grouped by IP address.

        :param str qd: A date range query parameter.

            Accepts:  ``since:YYYYMMDD``, ``between:YYYYMMDDhhmmss,YYYYMMDDhhmmss``, and ``daysBack:N``.

            Examples:  ``since:20190601``, ``between:20191001000000,20191002060000``, ``daysBack:30``

        :param domain: List of strings. The domains to filter on.
        :param trapSource: List of strings. The trap sources to filter on.

            Accepts:  ``ABUSIX``, ``CLOUDMARK``, ``SNDS``, ``GTN_PASSIVE``, ``GTN_ACTIVE``

        :param trapType: List of strings. The trap types to filter on.

            Accepts:  ``PRISTINE``, ``MIXED``, ``RECYCLED``, ``PARKED``, ``TYPO``

        :param ipAddress: List of strings. IP addresses to filter on. Accepts IP ranges, each IP range must be no
            larger that 256 IPs.
        :param int page: The page to query for in pagination.
        :param int per_page: The amount of records per page you wish to query for (max 100)
        :param str order: The property to sort by ('property' for decending, '-property' for ascending)

            Accepts:  ``ipAddress``, ``-ipAddress``, ``hitCountTotal``, ``-hitCountTotal``, ``hitCountRecycled``,
            ``-hitCountRecycled``, ``hitCountMixed``, ``-hitCountMixed``, ``hitCountParked``, ``-hitCountParked``,
            ``hitCountPristine``, ``-hitCountPristine``, ``hitCountTypo``, and ``-hitCountTypo``

        :return:  A ``list`` object of ``dict`` containing aggregated spam trap data
        """
        endpoint = ""
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse

    def get_ip_rollup(self, **kwargs):
        """
        Gets a list of aggregated detailed spam trap information and associated campaign information by IP address for
            sending domains. A details link is returned which can be used to retrieve the details for each of the spam
            trap hits included in the aggregated spam trap information.

        :param str qd: A date range query parameter.

            Accepts:  ``since:YYYYMMDD``, ``between:YYYYMMDDhhmmss,YYYYMMDDhhmmss``, and ``daysBack:N``.

            Examples:  ``since:20190601``, ``between:20191001000000,20191002060000``, ``daysBack:30``

        :param domain: List of strings. The domains to filter on.
        :param trapSource: List of strings. The trap sources to filter on.

            Accepts:  ``ABUSIX``, ``CLOUDMARK``, ``SNDS``, ``GTN_PASSIVE``, ``GTN_ACTIVE``

        :param trapType: List of strings. The trap types to filter on.

            Accepts:  ``PRISTINE``, ``MIXED``, ``RECYCLED``, ``PARKED``, ``TYPO``

        :param ipAddress: List of strings. IP addresses to filter on. Accepts IP ranges, each IP range must be no
            larger that 256 IPs.
        :param campaignIdentifier: List of strings. The campaign identifier used to identify the campaign when using a
            Campaign Identification method other than Subject/Date. Use the subjectLine filter if a domain is using
            Subject/Date to identify campaigns.
        :param subjectLine: List of strings. The subject lines to filter on.
        :param fromAddresses: List of strings. The "from" addresses to filter on.
        :param int page: The page to query for in pagination.
        :param int per_page: The amount of records per page you wish to query for (max 100)
        :param str order: The property to sort by ('property' for decending, '-property' for ascending)

            Accepts:  ``ipAddress``, ``-ipAddress``, ``hitCountTotal``, ``-hitCountTotal``, ``firstSeen``,
            ``-firstSeen``, ``lastSeen``, ``-lastSeen``, ``hitSources``, ``-hitSources``, ``trapTypes``, ``-trapTypes``,
            ``subjectLine``, ``-subjectLine``, ``campaign``,  and ``-campaign``.

        :return: A ``list`` object of ``dict`` containing spam trap data
        """
        endpoint = "/rollup"
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse

    def get_ip_rollup_details(self, **kwargs):
        """
        Gets a list of spam trap hits with detailed information. It is recommended that this endpoint be accessed
            using the details link returned by the ip/rollup endpoint. To retrieve details for a campaign you must set
            a campaignId OR subjectLine filter for the campaign of interest. If you do not set a campaignId OR
            subjectLine filter you will only get detailed hits without an associated campaign.

        :param str qd: A date range query parameter.

            Accepts:  ``since:YYYYMMDD``, ``between:YYYYMMDDhhmmss,YYYYMMDDhhmmss``, and ``daysBack:N``.

            Examples:  ``since:20190601``, ``between:20191001000000,20191002060000``, ``daysBack:30``

        :param domain: List of strings. The domains to filter on.
        :param trapSource: List of strings. The trap sources to filter on.

            Accepts:  ``ABUSIX``, ``CLOUDMARK``, ``SNDS``, ``GTN_PASSIVE``, ``GTN_ACTIVE``

        :param trapType: List of strings. The trap types to filter on.

            Accepts:  ``PRISTINE``, ``MIXED``, ``RECYCLED``, ``PARKED``, ``TYPO``

        :param ipAddress: List of strings. IP addresses to filter on. Accepts IP ranges, each IP range must be no
            larger that 256 IPs.
        :param int campaignId: The campaign id used to filter on.
        :param str subjectLine: The subject line to filter on.
        :param fromAddresses: List of strings. The "from" addresses to filter on.
        :param int page: The page to query for in pagination.
        :param int per_page: The amount of records per page you wish to query for (max 100)
        :param str order: The property to sort by ('property' for decending, '-property' for ascending)

            Accepts:  ``hitCountTotal``, ``-hitCountTotal``, ``firstSeen``, ``-firstSeen``, ``lastSeen``, ``-lastSeen``,
            ``ipAddress``, ``-ipAddress``, ``hitSources``, ``-hitSources``, ``subjectLine``,``-subjectLine``,
            ``fromAddress``, ``-fromAddress``, ``trapAgeDays``,  and ``-trapAgeDays``.

        :return: A ``list`` object of ``dict`` containing spam trap data.
        """
        endpoint = "/rollup/details"
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse


class Ping(Resource):
    key = "ping"

    def ping_service(self):
        """
        Ping the service to verify it is reachable.

        :return:  A ``str`` object.  A successful ping will return the string 'pong'.
        """
        endpoint = ""
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters({}, {})
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse



import responses
from inboxtracker import InboxTracker


@responses.activate
def test_get_available_domains():
    it = InboxTracker("fake-key")
    endpoint = ""
    url = it.spam_trap.available_domains.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.spam_trap.available_domains.get_available_domains()
    assert json_output == 'yay'

@responses.activate
def test_get_traps_by_domain():
    it = InboxTracker("fake-key")
    endpoint = ""
    url = it.spam_trap.domain.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.spam_trap.domain.get_traps_by_domain()
    assert json_output == 'yay'

@responses.activate
def test_get_domain_rollup():
    it = InboxTracker("fake-key")
    endpoint = "/rollup"
    url = it.spam_trap.domain.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.spam_trap.domain.get_domain_rollup()
    assert json_output == 'yay'

@responses.activate
def test_get_domain_rollup_details():
    it = InboxTracker("fake-key")
    endpoint = "/rollup/details"
    url = it.spam_trap.domain.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.spam_trap.domain.get_domain_rollup_details()
    assert json_output == 'yay'

@responses.activate
def test_get_traps_by_ip():
    it = InboxTracker("fake-key")
    endpoint = ""
    url = it.spam_trap.ip.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.spam_trap.ip.get_traps_by_ip()
    assert json_output == 'yay'

@responses.activate
def test_get_ip_rollup():
    it = InboxTracker("fake-key")
    endpoint = "/rollup"
    url = it.spam_trap.ip.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.spam_trap.ip.get_ip_rollup()
    assert json_output == 'yay'

@responses.activate
def test_get_ip_rollup_details():
    it = InboxTracker("fake-key")
    endpoint = "/rollup/details"
    url = it.spam_trap.ip.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.spam_trap.ip.get_ip_rollup_details()
    assert json_output == 'yay'



from .base import Resource


class Deliverability(Resource):

    key = "deliverability"

    param_model = {
        'childAccountId',
        'domain',
        'embed',
        'qd'
    }

    def get_deliverability_by_domain(self, domain, **kwargs):
        """
        Get deliverability information for a domain

        :param str domain:  The domain to show results for
        :param str qd:  A date range query parameter.

            Accepts:  ``since:YYYYMMDD``, ``between:YYYYMMDDhhmmss,YYYYMMDDhhmmss``, and ``daysBack:N``.

            Examples:  ``since:20190601``, ``between:20191001000000,20191002060000``, ``daysBack:30``
        :param int childAccountId:  The child account to narrow results
        :param str embed:  The objects within the return model you wish to embed.


            Accepts:  ``gmailCategories``, ``deliveryIndex``, ``ipDetails``

        :return:  A ``dict`` object containing details for a given domain.
        """

        endpoint = "/" + str(domain)
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, self.param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse



from .base import Resource


class Seeds(Resource):
    key = "seeds"

    param_model = {
        'childAccountId'
    }

    def get_last_update(self, **kwargs):
        """
        Get the time of the last update to the Traditional Seeds list

        :param int childAccountId:  The child account to narrow results

        :return:  A ``list`` object of ``dict`` containing the seed list ID, account ID, and last updated date
        """

        endpoint = "/lastUpdate"
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, self.param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse

    def get_usage(self, **kwargs):
        """
        Get the Traditional Seeds usage information for your account

        :param int childAccountId:  The child account to narrow results

        :return:  A ``list`` object of ``dict`` containing the usage details of the seed list.
        """

        endpoint = "/usage"
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, self.param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse

    def get_seeds(self, **kwargs):
        """
        Get an updated Traditional Seeds list

        :param int childAccountId:  The child account to narrow results

        :return:  A ``list`` object of ``dict`` containing the details of the seeds, such as the email address,
            location, and ISP.
        """

        endpoint = ""
        apiUrl = self.uri + endpoint
        parameters = self.SetParameters(kwargs, self.param_model)
        apiResponse = self.request("GET", apiUrl, params=parameters)

        return apiResponse



import responses
from inboxtracker import InboxTracker


@responses.activate
def test_get_available_domains():
    it = InboxTracker("fake-key")
    endpoint = "/available"
    url = it.domains.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.domains.get_available_domains()
    assert json_output == 'yay'



import responses
from inboxtracker import InboxTracker


@responses.activate
def test_get_domain_perf():
    it = InboxTracker("fake-key")
    endpoint = "/domain"
    url = it.postmaster_tools.yahoo.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.postmaster_tools.yahoo.get_domain_perf()
    assert json_output == 'yay'

@responses.activate
def test_get_ip_perf():
    it = InboxTracker("fake-key")
    endpoint = "/ip"
    url = it.postmaster_tools.yahoo.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.postmaster_tools.yahoo.get_ip_perf()
    assert json_output == 'yay'

@responses.activate
def test_get_volume_over_time():
    it = InboxTracker("fake-key")
    endpoint = "/volume/over-time"
    url = it.postmaster_tools.yahoo.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.postmaster_tools.yahoo.get_volume_over_time()
    assert json_output == 'yay'



from setuptools import setup, find_packages


setup(
    name='inboxtracker',
    version='1.2.1',
    author='Darren Smith',
    author_email='darren.smith@sparkpost.com',
    packages=find_packages(),
    url='https://github.com/darrensmith223/InboxTracker',
    license='Apache 2.0',
    description='Inbox Tracker Python API Library',
    install_requires=['requests>=2.20.1']
)


import responses
from inboxtracker import InboxTracker


@responses.activate
def test_get_intelliseeds():
    it = InboxTracker("fake-key")
    endpoint = ""
    url = it.intelliseeds.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.intelliseeds.get_intelliseeds()
    assert json_output == 'yay'


@responses.activate
def test_get_last_update():
    it = InboxTracker("fake-key")
    endpoint = "/lastUpdate"
    url = it.intelliseeds.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.intelliseeds.get_last_update()
    assert json_output == 'yay'


@responses.activate
def test_get_filter_sets():
    it = InboxTracker("fake-key")
    endpoint = "/filter_sets"
    url = it.intelliseeds.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.intelliseeds.get_filter_sets()
    assert json_output == 'yay'


@responses.activate
def test_get_intelliseeds_filtered():
    it = InboxTracker("fake-key")
    filterSetId = "test-filterSetId"
    endpoint = "/" + str(filterSetId)
    url = it.intelliseeds.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.intelliseeds.get_intelliseeds_filtered(filterSetId)
    assert json_output == 'yay'


@responses.activate
def test_create_intelliseed_filter():
    it = InboxTracker("fake-key")
    endpoint = "/filter_sets"
    url = it.intelliseeds.uri + endpoint
    responses.add(
        responses.POST,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.intelliseeds.create_intelliseed_filter(
        name="name",
        listType="PUBLIC",
        simulatedEngagementOption="ALL",
        percentOfList="test-pct",
        regions=["test-region"]
    )
    assert json_output == 'yay'


@responses.activate
def test_delete_intelliseed_filter():
    it = InboxTracker("fake-key")
    filterSetId = "test-filterSetId"
    endpoint = "/filter_sets/" + str(filterSetId)
    url = it.intelliseeds.uri + endpoint
    responses.add(
        responses.DELETE,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    json_output = it.intelliseeds.delete_intelliseed_filter(filterSetId)
    assert json_output == 'yay'



import responses
from inboxtracker import InboxTracker


@responses.activate
def test_ping_service():
    it = InboxTracker("fake-key")
    endpoint = ""
    url = it.ping.uri + endpoint
    responses.add(
        responses.GET,
        url,
        status=200,
        content_type='application/json',
        body='{"results": "yay"}'
    )
    output = it.ping.ping_service()
    assert output == "yay"
